<?php

/*
Plugin Name: Tab Slide
Plugin URI: http://wordpress.org/extend/plugins/tab-slide/
Description: Slide your target page into and out of the visible page with these very useful side tabs. The pages can contain forms, videos, pictures, posts, menu options, comments, logins, sign-ups, annoying popoup ads etc...There are a few templates included to get yourself started with more on the way. The settings page appears in the Dashboard where you can set all your tab slide options such as page source, size, positioning, autohide, opacity. This plugin is ideal for users who would like to add additional content without cluttering up or leaving the page.
Version: 1.1
Author: Zoran Cikojevic
License: GPL2
*/

// Define contants
define( 'TAB_SLIDE_VERSION' , '1.1' );
define( 'TAB_SLIDE_ROOT' , dirname(__FILE__) );
define( 'TAB_SLIDE_FILE_PATH' , TAB_SLIDE_ROOT . '/' . basename(__FILE__) );
define( 'TAB_SLIDE_URL' , plugins_url(plugin_basename(dirname(__FILE__)).'/') );
define( 'TAB_SLIDE_SETTINGS_PAGE' , 'admin.php?page=tab-slide/tab-slide' );

// Include necessary files, including the path in which to search to avoid conflicts
include_once( TAB_SLIDE_ROOT . '/php/settings.php' );
include_once( TAB_SLIDE_ROOT . '/php/upgrade.php' );

// Core class
class tab_slide {

	// Unique identifier added as a prefix to all options
	var $options_group = 'tab_slide_';
	// Initially stores default option values, but when load_options is run, it is populated with the options stored in the WP db
	var $options = array(
					"version" => 0,
					"show_on_load" => TRUE,
					"window_unit" => 'px',
					"open_width" => 200,
					"open_height" => 250,
					"open_top" => 30,
					"tab_top" => 55,
					"timer" => 2,
					"background" => "silver",
					"tab_image" => "images/tab_toggle.png",
					"tab_color" => "#fff",
					"window_url" => "wp-content/plugins/tab-slide/templates/signin.php",
					"opacity" => 80
				);		
	
	/**
	 * Constructor
	 */
	function __construct() {
		global $wpdb;
		
		load_plugin_textdomain( 'tab-slide', null, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

		// Load plugin options
		$this->load_options();
				
		// Create all of our objects
		$this->settings = new Tab_Slide_Settings();
		
		// Core hooks to initialize the plugin
		add_action( 'init', array( &$this,'init' ) );
		add_action( 'admin_init', array( &$this, 'admin_init' ) );
			
		// TAB SLIDE inits in a bunch of places all at the default priority.
		// This is run after all the init calls have been run.
		add_action( 'init', array( &$this, 'do_init_hook' ), 11 );
		
		// Add any necessary javascript
		//add_action('admin_enqueue_scripts', array(&$this, 'add_admin_scripts'));
		
	} // END __construct()
	
	/**
	 * Inititalizes the plugin
	 */
	function init() {
		if(is_admin()) {

			//Add the necessary pages for the plugin 
			add_action('admin_menu', array(&$this, 'add_menu_items'));			
		}
	} // END: init()
	
	/**
	 * do_init_hook()
	 * Call a custom hook for TAB SLIDE Extensions to hook into.
	 */
	function do_init_hook() {
		do_action( 'tab_init' );
		global $params;
		if(!is_admin()) {
			//disable plugin on wp-login page
			if ( !in_array( $GLOBALS['pagenow'], array( 'wp-login.php', 'wp-register.php' ) ) ){
			

				//wp_register_script('jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.4.3/jquery.min.js?ver=1.4.3', false, '1.4.3');
				wp_register_script('jquery', 'https://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js', false, '1.7.1');
				wp_enqueue_script('jquery');
				
				//JS TAB-SLIDE frontend
				wp_register_script('tab_tab_slider_script', ( TAB_SLIDE_URL . 'js/tab_slide.js'), false); 
				wp_enqueue_script('tab_tab_slider_script');
				wp_localize_script('tab_tab_slider_script', 'j_options', $params);
				
				//JS TAB-SLIDE settings
				wp_register_script('tab_tab_slider_content', ( TAB_SLIDE_URL . 'js/settings.js'), false); 
				wp_enqueue_script('tab_tab_slider_content');
				wp_localize_script('tab_tab_slider_content', 'j_options', $params);
				
				// CSS
				$myStyleUrl = TAB_SLIDE_URL . '/tab-slide.css';
				wp_register_style('tab_tab_slider_StyleSheet', $myStyleUrl);
				wp_enqueue_style( 'tab_tab_slider_StyleSheet');	
			}
		}		
	} // END: do_init_hook()	
	
	/**
	 * Initialize the plugin for the admin 
	 */
	function admin_init() {
		// Register all plugin settings so that we can change them and such
		foreach($this->options as $option => $value) {
	    	register_setting($this->options_group, $this->get_plugin_option_fullname($option));
	    }
	    	    
		// Upgrade if need be
		$tab_prev_version = $this->get_plugin_option('version');
		if ( version_compare( $tab_prev_version, TAB_SLIDE_VERSION, '<' ) ) tab_slide_upgrade($tab_prev_version);

		$this->register_scripts_and_styles();
		
	} // END: admin_init()
	
	/**
	 * This function is called when plugin is activated.
	 */
	function activate_plugin ( ) {
		global $wpdb;
		
		
	} // END: activate_plugin
	
	/**
	 * This function is called when plugin is activated.
	 */
	function deactivate_plugin( ) {
		
		$this->delete_options();
	} // END: deactivate_plugin

	/*
	 * Loads options for the plugin.
	 * If option doesn't exist in database, it is added
	 *
	 * Note: default values are stored in the $this->options array
	 * Note: a prefix unique to the plugin is appended to all options. Prefix is stored in $this->options_group 
	 */
	function load_options ( ) {

		$new_options = array();
		
		foreach($this->options as $option => $value) {
			$name = $this->get_plugin_option_fullname($option);
			$return = get_option($name);
			if($return === false) {
				add_option($name, $value);
				$new_array[$option] = $value;
			} else {
				$new_array[$option] = $return;
			}
		}
		
		$this->options = $new_array;
		$j_options = $this->options;
		$json_str = json_encode($j_options);
		
		
		global $params; 
		$params = array(
	    	'j_options' => $json_str
		);
		 
		
		
	} // END: load_options

	function delete_options() {
			
		$delete_options = array(
						'version',
						'show_on_load',
						'window_unit',
						'open_width',
						'open_height',
						'open_top',
						'background',
						'tab_image',
						'tab_color',
						'window_url',
						'opacity',
						'timer',
						'tab_top'
						);
						
		foreach($delete_options as $value) {
			
			$name = $this->get_plugin_option_fullname($value);
				delete_option($name);	
		}
	}

	/**
	 * Returns option for the plugin specified by $name, e.g. custom_stati_enabled
	 *
	 * Note: The plugin option prefix does not need to be included in $name 
	 * 
	 * @param string name of the option
	 * @return option|null if not found
	 *
	 */
	function get_plugin_option ( $name ) {
		if(is_array($this->options) && $option = $this->options[$name])
			return $option;
		else 
			return null;
	} // END: get_option
	
	// Utility function: appends the option prefix and returns the full name of the option as it is stored in the wp_options db
	function get_plugin_option_fullname ( $name ) {
		return $this->options_group . $name;
	}
	
	/**
	 * Updates option for the plugin specified by $name, e.g. show_on_load
	 *
	 * Note: The plugin option prefix does not need to be included in $name 
	 * 
	 * @param string name of the option
	 * @param string value to be set
	 *
	 */
	function update_plugin_option( $name, $new_value ) {
		if( is_array($this->options) /* && !empty( $this->options[$name] ) */ ) {
			$this->options[$name] = $new_value;
			update_option( $this->get_plugin_option_fullname( $name ), $new_value );
		}
	}
	/**
	 * Registers commonly used scripts + styles for easy enqueueing
	 */	
	function register_scripts_and_styles() {
		//wp_register_script('jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.4.3/jquery.min.js?ver=1.4.3', false, '1.4.3');
		wp_register_script('jquery', 'https://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js', false, '1.7.1');
		wp_enqueue_script('jquery');
	}	
	/**
	 * Adds menu items for the plugin
	 */
	function add_menu_items ( ) {
		
		/**
		 * Add Top-level Admin Menu
		 */
		add_menu_page(__('Tab Slide', 'tab-slide'), __('Tab Slide', 'tab-slide'), 'manage_options', $this->get_page('tab-slide'), array(&$this->settings, 'settings_page'));
				
	} // END: add_menu_items() 
	
	/**
	 * Gets the page string/path
	 * @param string $page
	 * @return string
	 */
	function get_page ( $page = '' ) {
		return 'tab-slide'. (($page) ? '/' . $page : '');
	}
	
	/**
	 * Adds necessary Javascript to admin
	 */
	function add_admin_scripts() {
		global $pagenow, $plugin_page;
		//wp_register_script('jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.4.3/jquery.min.js?ver=1.4.3', false, '1.4.3');
		wp_register_script('jquery', 'https://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js', false, '1.7.1');
		wp_enqueue_script('jquery');
		
		//wp_enqueue_script( 'tab_slide-js', TAB_SLIDE_URL.'js/tab_slide.js', array('jquery'), TAB_SLIDE_VERSION, true );
			
	}

} // END: class tab_slide

// Create new instance of the tab_slide object
global $tab_slide;
$tab_slide = new tab_slide();

/**
 * tab_loaded()
 * Allow dependent plugins and core actions to attach themselves in a safe way
 */
function tab_loaded() {
	do_action( 'tab_loaded' );
}
add_action( 'plugins_loaded', 'tab_loaded', 20 );

// Hook to perform action when plugin activated
register_activation_hook( TAB_SLIDE_FILE_PATH, array(&$tab_slide, 'activate_plugin'));
register_deactivation_hook( TAB_SLIDE_FILE_PATH, array(&$tab_slide, 'deactivate_plugin'));